diff src/message.c @ 15211:de63593896b3 v8.1.0615

patch 8.1.0615: get_tv function names are not consistent commit https://github.com/vim/vim/commit/d155d7a8519987361169459b8d464ae1caef5e9c Author: Bram Moolenaar <Bram@vim.org> Date: Fri Dec 21 16:04:21 2018 +0100 patch 8.1.0615: get_tv function names are not consistent Problem: Get_tv function names are not consistent. Solution: Rename to tv_get.
author Bram Moolenaar <Bram@vim.org>
date Fri, 21 Dec 2018 16:15:06 +0100
parents a527110d5f56
children dada0b389d4f
line wrap: on
line diff
--- a/src/message.c
+++ b/src/message.c
@@ -4137,7 +4137,7 @@ tv_nr(typval_T *tvs, int *idxp)
     else
     {
 	++*idxp;
-	n = get_tv_number_chk(&tvs[idx], &err);
+	n = tv_get_number_chk(&tvs[idx], &err);
 	if (err)
 	    n = 0;
     }
@@ -4146,7 +4146,7 @@ tv_nr(typval_T *tvs, int *idxp)
 
 /*
  * Get string argument from "idxp" entry in "tvs".  First entry is 1.
  * If "tofree" is NULL get_tv_string_chk() is used.  Some types (e.g. List)
  * are not converted to a string.
  * If "tofree" is not NULL echo_string() is used.  All types are converted to
  * a string with the same format as ":echo".  The caller must free "*tofree".
@@ -4167,7 +4167,7 @@ tv_str(typval_T *tvs, int *idxp, char_u 
 	if (tofree != NULL)
 	    s = (char *)echo_string(&tvs[idx], tofree, numbuf, get_copyID());
 	else
-	    s = (char *)get_tv_string_chk(&tvs[idx]);
+	    s = (char *)tv_get_string_chk(&tvs[idx]);
     }
     return s;
 }
@@ -4146,7 +4146,7 @@ tv_nr(typval_T *tvs, int *idxp)
 /*
  * Get string argument from "idxp" entry in "tvs".  First entry is 1.
- * If "tofree" is NULL get_tv_string_chk() is used.  Some types (e.g. List)
+ * If "tofree" is NULL tv_get_string_chk() is used.  Some types (e.g. List)
  * are not converted to a string.
  * If "tofree" is not NULL echo_string() is used.  All types are converted to